<?php

## This script adds teaser markup. A line beginning with 'T:WikiWord'
## gets converted to ':WikiWord:first paragraph of WikiWord'.
## Lines beginning with T* or T# get converted to list items.
##
## [[title:WikiWord]] gets converted to 'first paragraph'
##
## and WikiWord#Anchor retrieves a named paragraph
##
## Copyright 2002, 2003 John Rankin (john.rankin@affinity.co.nz)

$IdPattern = "[A-Za-z][-.:_A-Za-z0-9]*";

$DoubleBrackets["/^T([:*#]+|:(?:#|\\[\\[#$IdPattern\\]\\]))((\\[\\[)?($PageLinkPattern)((?:\\s.*?)\\]\\])?)/e"] 
  = 'TeaserText("$1","$2");';
$DoubleBrackets["/\\[\\[title:($PageLinkPattern)\\]\\]/e"]
  = 'FirstParagraph("$1");';
$DoubleBrackets["/\\[\\[para:($PageLinkPattern)\\]\\]/e"]
  = 'FirstParagraph("$1");';
$DoubleBrackets["/\\[\\[para:(($PageLinkPattern)#($IdPattern))\\]\\]/e"]
  = 'AnchorParagraph("$1");';

function TeaserText($markup,$word) {
  global $PageLinkPattern;
  if (preg_match("/^\\[\\[($PageLinkPattern)/",$word,$match)) {
      $pg = $match[1];
      $word = stripslashes($word);
  } else {
      $pg = $word;
  }
  if ($markup[0] == ":") $s = '';
  else $s = ' ';
  return "$markup$s$word:$s" . FirstParagraph($pg);
}

function FirstParagraph($word) {
  global $pagename,$ClassicFreeLinkPattern,$PageTitlePattern;
  $teasername = 
    preg_replace("/($ClassicFreeLinkPattern)/e",'Wikify("$1")',$word);
  if (preg_match("/^($PageTitlePattern)$/",$teasername))
    $teasername = FmtPageName("\$Group.$teasername",$pagename);
  $teaserpage = ReadPage($teasername);
  if ($teaserpage) {
    $teasergroup = FmtPageName('$Group',$teasername);
    $teaserpage['text'] .= "\n";
    $firstpara = substr($teaserpage['text'],0,strpos($teaserpage['text'],"\n"));
  }
  return CleanParagraph($teasergroup,$firstpara);
}

function AnchorParagraph($wordanchor) {
  global $pagename,$ClassicFreeLinkPattern,$PageTitlePattern;
  $teasername= preg_replace("/#.*$/","",$wordanchor);
  $teasername= 
    preg_replace("/($ClassicFreeLinkPattern)/e",'Wikify("$1")',$teasername);
  $anchor = preg_replace("/^.*#/","",$wordanchor);
  if (preg_match("/^($PageTitlePattern)$/",$teasername))
    $teasername = FmtPageName("\$Group.$teasername",$pagename);
  $teaserpage = ReadPage($teasername);
  if ($teaserpage) {
    $teasergroup = FmtPageName('$Group',$teasername);
    $teaserpage['text'] .= "\n";
    if (preg_match("/\\[\\[#$anchor\\]\\]\\n?(.*?)\\n/", $teaserpage['text'], $match)) {
       $para = CleanParagraph($teasergroup,$match[1]);
    } else {
       $para = "'''$anchor''' not found in $teasername.";
    }
  }
  return $para;
}

function CleanParagraph($group,$para) {
  global $GroupNamePattern,$PageLinkPattern,$pagename;
    $p = preg_replace("/^[#*!]+\s*/","",$para);
    $p = preg_replace("/^:.*?:/","",$p);
    $p = preg_replace("/`\\..*?$/","...",$p);
    $p = preg_replace("/\\[\\=(.*?)\\=\\]/se",
              "Keep(str_replace('\\\"','\"','$1'))",$p);
    $p = preg_replace("/\\[\\[#.*\\]\\]/","",$p);
    $p = preg_replace("/{{($GroupNamePattern)([\\/.])/",'$1$2{{',$p);
    $p = preg_replace("/($PageLinkPattern)/e", 'QualifyLink($group,"$1")', $p);
    $p = FmtPageName(preg_replace("/\\[\\[(\\$.*?)\\]\\]/",'$1',$p),$pagename);
  return $p;
}

?>